Index: src/crankshaft/x64/lithium-codegen-x64.cc |
diff --git a/src/crankshaft/x64/lithium-codegen-x64.cc b/src/crankshaft/x64/lithium-codegen-x64.cc |
index 43131e37e4130763384cf38f0f95a48cefc58b00..688904099682310f13c1c2aa586dfc7a6e358ad0 100644 |
--- a/src/crankshaft/x64/lithium-codegen-x64.cc |
+++ b/src/crankshaft/x64/lithium-codegen-x64.cc |
@@ -2822,11 +2822,11 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
__ j(not_equal, &done); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
// it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |
__ Cmp(FieldOperand(result, Cell::kValueOffset), |
- Smi::FromInt(Isolate::kArrayProtectorValid)); |
+ Smi::FromInt(Isolate::kProtectorValid)); |
DeoptimizeIf(not_equal, instr, DeoptimizeReason::kHole); |
} |
__ Move(result, isolate()->factory()->undefined_value()); |
@@ -2822,11 +2822,11 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
+ // protector cell contains (Smi) Isolate::kProtectorValid. Otherwise |
// it needs to bail out. |
__ LoadRoot(result, Heap::kArrayProtectorRootIndex); |